# -*- coding: utf-8 -*-

# CGNES - Coarse-Grained Nuclear Envelope Simulator
# Copyright 2021 Pranjal Singh
#
# See the README file in the top-level CGNES directory.
# This software is released under the GNU General Public License.

# -----------------------------------------------------------------------------
# This file plots force-depth curve for indentation of NE.
#
# Pranjal Singh (orcid.org/0000-0003-3722-2590)
# The Pennsylvania State University
# Contact: pxs392@psu.edu (current); pranjal.officemail@gmail.com (permanent)
# -----------------------------------------------------------------------------

# date             :06/19/2021
# version          :0.8.2
# usage            :gnuplot indentation.gp
# gnuplot_version  :5.2.7

set term svg size 500,400 font "Arial,18"
# font "Times-Roman,22"
set output 'indentation.svg'
set encoding utf8

# set key outside
set key box opaque
# set key horiz
set key font ",16"
#set key off

# Parameters
R = 1.00 # in μm, radius of indenter
z0 = R*100+5.0 # initial indenter position (in sigma)
scl = 1.8 # convert epsilon/sigma to pN
ddot = 30*900 # in μm/s
Ec = 1000.0 # in Pa
Zc = 1000.0 # in Pa-s

# Data
file1 = "../data/indentforce1.txt"

# Expected curve around this
f(x) = (4.0/3.0)*Ec*(R**0.5)*(x**1.5)+(2.0/3.0)*Zc*(R**0.5)*(ddot)*(x**0.5)

set ylabel 'Force, F (pN)'
set xlabel 'Depth, d (nm)'
set xrange [-50:200]
set yrange [0:400]
# set xtics 0.5
plot f(0.001*x) w l lw 2 lc rgb 'blue' title 'VCM theory', \
     file1 u ((R*100-$2)*10):($3*scl) sm mcs lw 2 lc rgb 'black' title 'CGNE'

quit
