# -*- coding: utf-8 -*-

# CGNES - Coarse-Grained Nuclear Envelope Simulator
# Copyright 2021 Pranjal Singh
#
# See the README file in the top-level CGNES directory.
# This software is released under the GNU General Public License.

# -----------------------------------------------------------------------------
# This file plots stress-strain curve from shearing of NE.
#
# Pranjal Singh (orcid.org/0000-0003-3722-2590)
# The Pennsylvania State University
# Contact: pxs392@psu.edu (current); pranjal.officemail@gmail.com (permanent)
# -----------------------------------------------------------------------------

# date             :06/19/2021
# version          :0.8.2
# usage            :gnuplot shear.gp
# gnuplot_version  :5.2.7

set term svg size 500,400 font "Arial,18"
# font "Times-Roman,22"
set output 'shear.svg'
set encoding utf8

# set key outside
set key box opaque
# set key horiz
set key font ",16"
#set key off

file = "../data/stress.txt"

G = 3*500 # in Pa
nu = 0.5
etacP = 3*1.0 # in cP
eta = etacP/1000 # in Pa-s
xyrate = 27000 # in micron per sec.
Ly = 2.5 # in micron
c = xyrate/Ly
f(x) = G*x + eta*c

UCy = (1.8e-20)/((10e-9)**3) # epsilon/sigma^3 to Pa

set ylabel 'Shear stress, τ_{xy} (Pa)'
set xlabel 'Shear strain, γ_{xy}'
set xrange [0:0.1]
set yrange [0:300]
# set xtics 0.1
set samples 30
plot f(x) w l lw 2 lc rgb 'black' title '2DV theory', \
     file u ($2):($3*UCy) smooth csplines lw 2 lc rgb '#7030a0' title 'CGNE'

quit
