#!/bin/bash
# -*- coding: utf-8 -*-

# CGNES - Coarse-Grained Nuclear Envelope Simulator
# Copyright 2021 Pranjal Singh
#
# See the README file in the top-level CGNES directory.
# This software is released under the GNU General Public License.

# -----------------------------------------------------------------------------
# This file (pc.sh) is for generating pc.data.
#
# Pranjal Singh (orcid.org/0000-0003-3722-2590)
# The Pennsylvania State University
# Contact: pxs392@psu.edu (current); pranjal.officemail@gmail.com (permanent)
# -----------------------------------------------------------------------------

# date         :06/19/2021
# version      :0.8.2
# usage        :./pc.sh
# sh_version   :4.2.46(2)-release

echo "Enter 'Y' or 'y' for yes."

read -p "Set up for run?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    make
    ./senescence.sh 1.0 2.0 0 run_dir
    make clean
fi

read -p "Run on cluster?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    cd run_dir
    cd sene*
    mv sene* init.lmp
    cp ../../init.qsub .
    qsub init.qsub
    touch data/init.out
    watch -n 1 "tail -10 data/init.out; qstat -u pxs392"
fi

read -p "Run on local?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    cd run_dir
    cd sene*
    mv sene* init.lmp
    ulimit -s 10240
    module purge
    module load mylammps
    mpirun lmp_mylammps < init.lmp > data/init.out &
    watch -n 1 "tail -10 data/init.out"
fi

exit 0
