#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# CGNES - Coarse-Grained Nuclear Envelope Simulator
# Copyright 2021 Pranjal Singh
#
# See the README file in the top-level CGNES directory.
# This software is released under the GNU General Public License.

# -----------------------------------------------------------------------------
# This file (dump2spatial.py) converts LAMMPS dumped data to time-sampled
# spatial data.
#
# Pranjal Singh (orcid.org/0000-0003-3722-2590)
# The Pennsylvania State University
# Contact: pxs392@psu.edu (current); pranjal.officemail@gmail.com (permanent)
# -----------------------------------------------------------------------------

# date         :06/19/2021
# version      :0.8.2
# usage        :python2 dump2spatial.py inFile outFile
# py_version   :2.7

import sys,os,math
# Numpy
# can be installed with "conda install numpy"
import numpy as np
# Scipy
# can be installed with "conda install -c anaconda scipy"
import scipy.io as sio
# Pizza.py
# can be obtained from https://github.com/lammps/pizza
# export its path as LAMMPS_PYTHON_TOOLS
path = os.environ["LAMMPS_PYTHON_TOOLS"]
sys.path.append(path)

from dump import dump
inFileName = sys.argv[1]
outFileName = sys.argv[2]

d = dump(inFileName)

ttotal = d.time()
dstacks = np.zeros((len(ttotal),), dtype=np.object)

for t in range(0,len(ttotal)):
	dstacks[t] = np.array(np.transpose(d.vecs(ttotal[t],'x','y','z')))

sio.savemat(outFileName, {'c':dstacks})
