# -*- coding: utf-8 -*-

# CGNES - Coarse-Grained Nuclear Envelope Simulator
# Copyright 2021 Pranjal Singh
#
# See the README file in the top-level CGNES directory.
# This software is released under the GNU General Public License.

# -----------------------------------------------------------------------------
# This file plots fluctuation spectra from NE morphology.
#
# Pranjal Singh (orcid.org/0000-0003-3722-2590)
# The Pennsylvania State University
# Contact: pxs392@psu.edu (current); pranjal.officemail@gmail.com (permanent)
# -----------------------------------------------------------------------------

# date             :06/19/2021
# version          :0.8.2
# usage            :gnuplot spectra.gp
# gnuplot_version  :5.2.7

set term svg size 500,400 font "Arial,18"
# font "Times-Roman,22"
set output 'spectra.svg'
set encoding utf8

# set key outside
set key box opaque
# set key horiz
set key font ",16"
#set key off

# Parameters
Lc = 6200.0 # contour length of nucleus
L = 250.0 # size of NE patch in the simulation

# Data
expfile = "spectra-exp.txt"
simfile = "freq.dat"
uq2a(x) = (Lc**2)*(L**2)*gam
uq2b(x) = 16*(pi**4)*c*((L/Lc)**2)*x**4
uq2c(x) = 4*(pi**2)*e*(L**2)*x**2
uq2(x) = (Lc/100)**2/(uq2a(x) + uq2b(x) + uq2c(x))

# Data bounds
qmin = 10
qmax = 200
k_sim = 1
q_sim = k_sim*Lc/L
q_exp = 60
set arrow from q_sim, graph 0 to q_sim, graph 1 nohead lw 1 lc rgb "black"
set arrow from q_exp, graph 0 to q_exp, graph 1 nohead lw 1 lc rgb "dark-red"

# Fitting
c = 32.0 # in kBT
e = 0.02 # in kBT/sig2
gam = 0.8/(L**2) # in kBT/sig4
set xrange [qmin:q_exp] # fitting range
fit uq2(x) expfile via c,e,gam

# Axes
set xrange [qmin:qmax]
set yrange [1e-8:1e-2]
set format x "10^{%L}"
set format y "10^{%L}"
set logscale x 10
set logscale y 10
set xtics 10
set ylabel 'Mean-squared amplitude <u_q^{2}> (μm^2)'
set xlabel 'Wavenumber, q'

# Plot
plot expfile u 1:2 pt 7 ps 0.7 lc rgb '#ffc000' title 'Experiments', \
     simfile u (Lc/(L/$1)):($2*1e-4) pt 7 ps 0.7 lc rgb '#7030a0' title 'CGNE', \
     uq2(x) w l lw 2 lc rgb 'black' title 'CMF theory'

quit
