#!/bin/bash
# -*- coding: utf-8 -*-

# CGNES - Coarse-Grained Nuclear Envelope Simulator
# Copyright 2021 Pranjal Singh
#
# See the README file in the top-level CGNES directory.
# This software is released under the GNU General Public License.

# -----------------------------------------------------------------------------
# This file (run.sh) is used to run and monitor simulations.
#
# Pranjal Singh (orcid.org/0000-0003-3722-2590)
# The Pennsylvania State University
# Contact: pxs392@psu.edu (current); pranjal.officemail@gmail.com (permanent)
# -----------------------------------------------------------------------------

# date         :06/19/2021
# version      :0.8.2
# usage        :./run.sh
# sh_version   :4.2.46(2)-release

echo "Enter 'Y' or 'y' for yes."

read -p "Run assembly on cluster?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    # Submit init.qsub to cluster
    qsub init.qsub
    # Ensure data directory is present
    mkdir -p data
    # Ensure output file exists
    touch data/init.out
    # Live PBS job status (replace pxs392 with your username)
    watch -n 1 "tail -10 data/init.out; qstat -u pxs392"
fi

read -p "Run simulation on cluster?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    qsub sim.qsub
    # Ensure data directory is present
    mkdir -p data
    # Ensure output file exists
    touch data/sim.out
    # Live PBS job status (replace pxs392 with your username)
    watch -n 1 "tail -10 data/sim.out; qstat -u pxs392"
fi

read -p "Run assembly on local machine?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    # cp init.lmp bkp.init.lmp
    ulimit -s 10240
    # Ensure data directory is present
    mkdir -p data
    # Load LAMMPS using module system
    module purge
    module load mylammps
    # Parallel run
    mpirun lmp_mylammps < init.lmp > data/init.out &
    watch -n 1 "tail -10 data/init.out"
fi

read -p "Run simulation on local machine?" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
    # cp sim.lmp bkp.sim.lmp
    ulimit -s 10240
    # Ensure data directory is present
    mkdir -p data
    # Load LAMMPS using module system
    module purge
    module load mylammps
    # Parallel run
    mpirun lmp_mylammps < sim.lmp > data/sim.out &
    watch -n 1 "tail -10 data/sim.out"
fi

exit 0
